import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/anchor/vue';
import { AutoTip } from '@opentinyvue/vue-directive';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Anchor",
  directives: {
    AutoTip
  },
  props: [].concat(props, ["isAffix", "links", "containerId", "markClass", "type"]),
  emits: ["linkClick", "change"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  },
  render: function render() {
    var h = arguments[0];
    var isAffix = this.isAffix, links = this.links, linkClick = this.linkClick, currentLink = this.state.currentLink, type = this.type;
    var _renderLinks = function renderLinks(links2) {
      return Array.isArray(links2) ? links2.map(function(item) {
        return h("div", {
          "attrs": {
            "data-tag": "tiny-anchor-link"
          },
          "class": [type === "line" && "ml-4 cursor-pointer leading-9", type === "dot" && "relative pl-2.5"],
          "key": item.key
        }, [h("a", {
          "attrs": {
            "data-tag": "tiny-anchor-link-title",
            "href": item.link
          },
          "class": ["whitespace-nowrap", type === "line" && "block max-w-full overflow-hidden text-ellipsis text-color-text-primary hover:text-color-brand", type === "dot" && "before:content-[''] before:block before:w-2 before:h-2 before:absolute after:content-[''] after:w-px after:block after:absolute", currentLink === item.link && "text-color-brand"],
          "on": {
            "click": function click(e) {
              return linkClick(e, item);
            }
          },
          "ref": item.link,
          "directives": [{
            name: "auto-tip",
            value: true
          }]
        }, [item.title]), item.children ? _renderLinks(item.children) : null]);
      }) : null;
    };
    var renderMask = h("div", {
      "attrs": {
        "data-tag": "tiny-anchor-link-mask"
      },
      "class": "absolute rounded-r-xl max-w-0 left-0.5 w-full",
      "ref": "maskRef"
    });
    var renderOrbit = h("div", {
      "attrs": {
        "data-tag": "tiny-anchor-orbit"
      },
      "class": "absolute left-0 -top-0 bottom-0 w-1 rounded bg-color-border"
    }, [h("div", {
      "attrs": {
        "data-tag": "tiny-anchor-orbit-skid"
      },
      "class": "absolute left-0 w-1 bg-color-brand rounded",
      "ref": "skidRef"
    })]);
    return h("div", {
      "attrs": {
        "data-tag": "tiny-anchor__wrapper"
      },
      "class": [isAffix ? "fixed z-10" : "", type === "line" && "", type === "dot" && "w-50"],
      "ref": "anchorWrapRef"
    }, [h("div", {
      "attrs": {
        "data-tag": "tiny-anchor"
      },
      "class": [type === "line" && "w-50 relative text-color-text-primary text-sm", type === "dot" && "px-4"],
      "ref": "anchorRef"
    }, [type === "line" && renderMask, type === "line" && renderOrbit, links && _renderLinks(links)])]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
