import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/anchor/vue';
import { AutoTip } from '@opentinyvue/vue-directive';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Anchor",
  directives: {
    AutoTip
  },
  props: [].concat(props, ["isAffix", "links", "containerId", "markClass", "type", "offsetTop"]),
  emits: ["linkClick", "onChange", "change"],
  // deprecated v3.12.0废弃，v3.17.0移除onChange 事件
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  },
  render: function render() {
    var h = arguments[0];
    var isAffix = this.isAffix, links = this.links, linkClick = this.linkClick, currentLink = this.state.currentLink, type = this.type;
    var anchorClass = "tiny-anchor";
    var _renderLinks = function renderLinks(links2) {
      return Array.isArray(links2) ? links2.map(function(item) {
        return h("div", {
          "class": anchorClass + "-link",
          "key": item.key
        }, [h("a", {
          "attrs": {
            "href": item.link
          },
          "class": [anchorClass + "-link-title", currentLink === item.link && anchorClass + "-link-title--active"],
          "on": {
            "click": function click(e) {
              return linkClick(e, item);
            }
          },
          "ref": item.link,
          "directives": [{
            name: "auto-tip",
            value: true
          }]
        }, [item.title]), item.children ? _renderLinks(item.children) : null]);
      }) : null;
    };
    var renderMask = h("div", {
      "class": anchorClass + "-link-mask",
      "ref": "maskRef"
    });
    var renderOrbit = h("div", {
      "class": anchorClass + "-orbit"
    }, [h("div", {
      "class": anchorClass + "-orbit-skid",
      "ref": "skidRef"
    })]);
    return h("div", {
      "class": [isAffix ? anchorClass + "__affix" : "", anchorClass + "__wrapper", "tiny-anchor__" + type],
      "ref": "anchorWrapRef"
    }, [h("div", {
      "class": anchorClass,
      "ref": "anchorRef"
    }, [type === "line" && renderMask, type === "line" && renderOrbit, links && _renderLinks(links)])]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
